pub fn create_element_with_flags<Sink>(
sink: &Sink,
name: QualName,
attrs: Vec<Attribute>,
had_duplicate_attributes: bool,
) -> Sink::Handlewhere
Sink: TreeSink,Expand description
A constructor for an element with duplicate attribute information.
This variant allows passing whether duplicate attributes were encountered during tokenization, which is needed for CSP nonce validation.